@@ -1,10 +1,9 @@
 import os
 import copy
 import random
+import asyncio
 import logging
 
-import regex
-
 import synapse.exc as s_exc
 import synapse.common as s_common
 import synapse.daemon as s_daemon
@@ -13,12 +12,74 @@ import synapse.telepath as s_telepath
 import synapse.lib.cell as s_cell
 import synapse.lib.coro as s_coro
 import synapse.lib.nexus as s_nexus
+import synapse.lib.config as s_config
+import synapse.lib.httpapi as s_httpapi
 import synapse.lib.msgpack as s_msgpack
 import synapse.lib.jsonstor as s_jsonstor
 import synapse.lib.lmdbslab as s_lmdbslab
 
 logger = logging.getLogger(__name__)
 
+_provSvcSchema = {
+    'type': 'object',
+    'properties': {
+        'name': {
+            'type': 'string',
+            'minLength': 1,
+        },
+        'provinfo': {
+            'type': 'object',
+            'properties': {
+                'conf': {
+                    'type': 'object',
+                },
+                'dmon:port': {
+                    'type': 'integer',
+                    'minimum': 0,
+                    'maximum': 65535,
+                },
+                'https:port': {
+                    'type': 'integer',
+                    'minimum': 0,
+                    'maximum': 65535,
+                },
+                'mirror': {
+                    'type': 'string',
+                    'minLength': 1,
+                },
+            }
+        }
+    },
+    'additionalProperties': False,
+    'required': ['name'],
+}
+provSvcSchema = s_config.getJsValidator(_provSvcSchema)
+
+class AhaProvisionServiceV1(s_httpapi.Handler):
+
+    async def post(self):
+        if not await self.reqAuthAdmin():
+            return
+
+        body = self.getJsonBody(validator=provSvcSchema)
+        if body is None:
+            return
+
+        name = body.get('name')
+        provinfo = body.get('provinfo')
+
+        try:
+            url = await self.cell.addAhaSvcProv(name, provinfo=provinfo)
+        except asyncio.CancelledError:  # pragma: no cover
+            raise
+        except s_exc.SynErr as e:
+            logger.exception(f'Error provisioning {name}')
+            return self.sendRestErr(e.__class__.__name__, e.get('mesg', str(e)))
+        except Exception as e:  # pragma: no cover
+            logger.exception(f'Error provisioning {name}')
+            return self.sendRestErr(e.__class__.__name__, str(e))
+        return self.sendRestRetn({'url': url})
+
 class AhaApi(s_cell.CellApi):
 
     async def getAhaUrls(self):
@@ -86,10 +147,11 @@ class AhaApi(s_cell.CellApi):
         async def fini():
             if self.cell.isfini:  # pragma: no cover
                 mesg = f'{self.cell.__class__.__name__} is fini. Unable to set {name}@{network} as down.'
-                logger.warning(mesg)
+                logger.warning(mesg, await self.cell.getLogExtra(name=svcname, netw=svcnetw))
                 return
 
-            logger.debug(f'AhaCellApi fini, tearing down [{name}]')
+            logger.debug(f'AhaCellApi fini, tearing down [{name}]',
+                         extra=await self.cell.getLogExtra(name=svcname, netw=svcnetw))
             coro = self.cell.setAhaSvcDown(name, sess, network=network)
             self.cell.schedCoro(coro)  # this will eventually execute or get cancelled.
 
@@ -181,10 +243,18 @@ class ProvDmon(s_daemon.Daemon):
         provinfo = await self.aha.getAhaSvcProv(name)
         if provinfo is not None:
             await self.aha.delAhaSvcProv(name)
+            conf = provinfo.get('conf', {})
+            anam = conf.get('aha:name')
+            anet = conf.get('aha:network')
+            mesg = f'Retrieved service provisioning info for {anam}.{anet} iden {name}'
+            logger.debug(mesg, extra=await self.aha.getLogExtra(iden=name, name=anam, netw=anet))
             return ProvApi(self.aha, provinfo)
 
         userinfo = await self.aha.getAhaUserEnroll(name)
         if userinfo is not None:
+            unam = userinfo.get('name')
+            mesg = f'Retrieved user provisioning info for {unam} iden {name}'
+            logger.debug(mesg, extra=await self.aha.getLogExtra(iden=name, name=unam))
             await self.aha.delAhaUserEnroll(name)
             return EnrollApi(self.aha, userinfo)
 
@@ -303,6 +373,10 @@ class AhaCell(s_cell.Cell):
         self.slab.initdb('aha:provs')
         self.slab.initdb('aha:enrolls')
 
+    def _initCellHttpApis(self):
+        s_cell.Cell._initCellHttpApis(self)
+        self.addHttpApi('/api/v1/aha/provision/service', AhaProvisionServiceV1, {'cell': self})
+
     async def initServiceRuntime(self):
         self.addActiveCoro(self._clearInactiveSessions)
 
@@ -347,7 +421,8 @@ class AhaCell(s_cell.Cell):
             network = svc.get('svcnetw')
             linkiden = svc.get('svcinfo').get('online')
             if linkiden not in current_sessions:
-                logger.debug(f'AhaCell activecoro tearing down [{svcname}.{network}]')
+                logger.debug(f'AhaCell activecoro tearing down [{svcname}.{network}]',
+                             extra=await self.getLogExtra(name=svcname, netw=network))
                 await self.setAhaSvcDown(svcname, linkiden, network=network)
 
         # Wait until we are cancelled or the cell is fini.
@@ -402,7 +477,8 @@ class AhaCell(s_cell.Cell):
         path = ('aha', 'services', svcnetw, svcname)
 
         unfo = info.get('urlinfo')
-        logger.debug(f'Adding service [{svcfull}] from [{unfo.get("scheme")}://{unfo.get("host")}:{unfo.get("port")}]')
+        logger.debug(f'Adding service [{svcfull}] from [{unfo.get("scheme")}://{unfo.get("host")}:{unfo.get("port")}]',
+                     extra=await self.getLogExtra(name=svcname, netw=svcnetw))
 
         svcinfo = {
             'name': svcfull,
@@ -456,7 +532,8 @@ class AhaCell(s_cell.Cell):
 
         await self.fire('aha:svcdown', svcname=svcname, svcnetw=svcnetw)
 
-        logger.debug(f'Set [{svcfull}] offline.')
+        logger.debug(f'Set [{svcfull}] offline.',
+                     extra=await self.getLogExtra(name=svcname, netw=svcnetw))
 
     async def getAhaSvc(self, name, filters=None):
 
@@ -527,7 +604,8 @@ class AhaCell(s_cell.Cell):
             with open(path, 'rb') as fd:
                 return fd.read().decode()
 
-        logger.info(f'Generating CA certificate for {network}')
+        logger.info(f'Generating CA certificate for {network}',
+                    extra=await self.getLogExtra(netw=network))
         fut = s_coro.executor(self.certdir.genCaCert, network, save=False)
         pkey, cert = await fut
 
@@ -601,7 +679,8 @@ class AhaCell(s_cell.Cell):
         if signas is None:
             signas = hostname.split('.', 1)[1]
 
-        logger.info(f'Signing host CSR for [{hostname}], signas={signas}, sans={sans}')
+        logger.info(f'Signing host CSR for [{hostname}], signas={signas}, sans={sans}',
+                    extra=await self.getLogExtra(hostname=hostname, signas=signas))
 
         pkey, cert = self.certdir.signHostCsr(xcsr, signas=signas, sans=sans)
 
@@ -619,7 +698,8 @@ class AhaCell(s_cell.Cell):
         if signas is None:
             signas = username.split('@', 1)[1]
 
-        logger.info(f'Signing user CSR for [{username}], signas={signas}')
+        logger.info(f'Signing user CSR for [{username}], signas={signas}',
+                    extra=await self.getLogExtra(name=username, signas=signas))
 
         pkey, cert = self.certdir.signUserCsr(xcsr, signas=signas)
 
@@ -678,7 +758,13 @@ class AhaCell(s_cell.Cell):
         hostname = f'{name}.{netw}'
 
         conf.setdefault('aha:name', name)
-        conf.setdefault('dmon:listen', f'ssl://0.0.0.0:0?hostname={hostname}&ca={netw}')
+        dmon_port = provinfo.get('dmon:port', 0)
+        dmon_listen = f'ssl://0.0.0.0:{dmon_port}?hostname={hostname}&ca={netw}'
+        conf.setdefault('dmon:listen', dmon_listen)
+
+        https_port = provinfo.get('https:port', s_common.novalu)
+        if https_port is not s_common.novalu:
+            conf.setdefault('https:port', https_port)
 
         # if the relative name contains a dot, we are a mirror peer.
         peer = name.find('.') != -1
@@ -712,7 +798,8 @@ class AhaCell(s_cell.Cell):
 
         iden = await self._push('aha:svc:prov:add', provinfo)
 
-        logger.debug(f'Created provisioning for {name}.{netw}')
+        logger.debug(f'Created service provisioning for {name}.{netw} with iden {iden}',
+                     extra=await self.getLogExtra(iden=iden, name=name, netw=netw))
 
         return self._getProvClientUrl(iden)
 
@@ -789,6 +876,10 @@ class AhaCell(s_cell.Cell):
         }
 
         iden = await self._push('aha:enroll:add', userinfo)
+
+        logger.debug(f'Created user provisioning for {name} with iden {iden}',
+                     extra=await self.getLogExtra(iden=iden, name=name))
+
         return self._getProvClientUrl(iden)
 
     async def getAhaUserEnroll(self, iden):
