@@ -140,6 +140,7 @@ class Config(c_abc.MutableMapping):
         self._argparse_conf_names = {}
         self._argparse_conf_parsed_names = {}
         self.envar_prefixes = envar_prefixes
+        self._opts_data = argparse.Namespace()
         self.validator = getJsValidator(self.json_schema)
         self._prop_schemas = {}
         self._prop_validators = {}
@@ -153,6 +154,9 @@ class Config(c_abc.MutableMapping):
         # Copy the data in so that it is validated.
         for k, v in conf.items():
             self[k] = v
+        # Ensure we're able to parse opts data for our schema -
+        # this populates the opts mapping data.
+        _ = self.getArgParseArgs()
 
     @classmethod
     def getConfFromCell(cls, cell, conf=None, envar_prefixes=None):
@@ -220,7 +224,7 @@ class Config(c_abc.MutableMapping):
             _ = self.getArgParseArgs()
         return {k: v for k, v in self._argparse_conf_parsed_names.items()}
 
-    def setConfFromOpts(self, opts):
+    def setConfFromOpts(self, opts=None):
         '''
         Set the opts for a conf object from a namespace object.
 
@@ -231,6 +235,8 @@ class Config(c_abc.MutableMapping):
         Returns:
             None: Returns None.
         '''
+        if opts is None:
+            opts = self._opts_data
         opts_data = vars(opts)
         for k, v in opts_data.items():
             if v is None:
@@ -239,17 +245,32 @@ class Config(c_abc.MutableMapping):
             if nname is None:
                 continue
             self.setdefault(nname, v)
+        self._opts_data = opts
 
-    def setConfFromFile(self, path):
+    def setConfFromFile(self, path, force=False):
         '''
         Set the opts for a conf object from YAML file path.
+
+        Args:
+            path (str): Path to the yaml load. If it exists, it must represent a dictionary.
+            force (bool): Force the update instead of using setdefault() behavior.
+
+        Returns:
+            None
         '''
         item = s_common.yamlload(path)
         if item is None:
             return
 
         for name, valu in item.items():
-            self.setdefault(name, valu)
+            if force:
+                oldv = self.get(name, s_common.novalu)
+                self[name] = valu
+                if oldv is s_common.novalu:
+                    continue
+                logger.info(f'Set configuration override for [{name}] from [{path}]')
+            else:
+                self.setdefault(name, valu)
 
     # Envar support methods
     def setConfFromEnvs(self):
