@@ -59,13 +59,13 @@ terminalEnglishMap = {
     'IF': 'if',
     'IN': 'in',
     'LBRACE': '{',
+    'LISTTOKN': 'unquoted list value',
     'LPAR': '(',
     'LSQB': '[',
     'MODSET': '+= or -=',
     'NONQUOTEWORD': 'unquoted value',
     'NOT': 'not',
     'NUMBER': 'number',
-    'NUMBERWS': 'number followed by whitespace',
     'OR': 'or',
     'PROPS': 'absolute property name',
     'RBRACE': '}',
@@ -102,6 +102,8 @@ terminalEnglishMap = {
     '_EMBEDQUERYSTART': '${',
     '_EMIT': 'emit',
     '_FINI': 'fini',
+    '_HASH': '#',
+    '_HASHSPACE': '#',
     '_INIT': 'init',
     '_LEFTJOIN': '<+-',
     '_LEFTPIVOT': '<-',
@@ -156,14 +158,27 @@ class AstConverter(lark.Transformer):
 
         return kid
 
+    def _parseJsonToken(self, meta, tokn):
+        if isinstance(tokn, lark.lexer.Token) and tokn.type == 'VARTOKN' and not tokn.value[0] in ('"', "'"):
+            valu = tokn.value
+            try:
+                valu = float(valu) if '.' in valu else int(valu, 0)
+            except ValueError as e:
+                mesg = f"Unexpected unquoted string in JSON expression at line {meta.line} col {meta.column}"
+                raise s_exc.BadSyntax(mesg=mesg, at=meta.start_pos, line=meta.line, column=meta.column)
+
+            return s_ast.Const(valu)
+        else:
+            return self._convert_child(tokn)
+
     @lark.v_args(meta=True)
     def exprlist(self, meta, kids):
-        kids = [self._convert_child(k) for k in kids]
+        kids = [self._parseJsonToken(meta, k) for k in kids]
         return s_ast.ExprList(kids=kids)
 
     @lark.v_args(meta=True)
     def exprdict(self, meta, kids):
-        kids = [self._convert_child(k) for k in kids]
+        kids = [self._parseJsonToken(meta, k) for k in kids]
         return s_ast.ExprDict(kids=kids)
 
     @lark.v_args(meta=True)
@@ -422,7 +437,12 @@ class AstConverter(lark.Transformer):
         if not isinstance(kid, lark.lexer.Token):
             return self._convert_child(kid)
 
-        kids = self._tagsplit(kid.value)
+        valu = kid.value
+        if '*' in valu:
+            mesg = f"Invalid wildcard usage in tag {valu}"
+            raise s_exc.BadSyntax(mesg=mesg, tag=valu)
+
+        kids = self._tagsplit(valu)
         return s_ast.TagName(kids=kids)
 
     def switchcase(self, kids):
@@ -601,7 +621,6 @@ terminalClassMap = {
     'DOUBLEQUOTEDSTRING': lambda x: s_ast.Const(unescape(x)),  # drop quotes and handle escape characters
     'TRIPLEQUOTEDSTRING': lambda x: s_ast.Const(x[3:-3]), # drop the triple 's
     'NUMBER': lambda x: s_ast.Const(s_ast.parseNumber(x)),
-    'NUMBERWS': lambda x: s_ast.Const(s_ast.parseNumber(x)),
     'HEXNUMBER': lambda x: s_ast.Const(s_ast.parseNumber(x)),
     'BOOL': lambda x: s_ast.Bool(x == 'true'),
     'SINGLEQUOTEDSTRING': lambda x: s_ast.Const(x[1:-1]),  # drop quotes
@@ -676,7 +695,6 @@ ruleClassMap = {
     'n2walk': s_ast.N2Walk,
     'n1walknpivo': s_ast.N1WalkNPivo,
     'n2walknpivo': s_ast.N2WalkNPivo,
-    'nonquotewords': lambda kids: s_ast.Const(' '.join([str(k.valu) for k in kids])),
     'notcond': s_ast.NotCond,
     'opervarlist': s_ast.VarListSetOper,
     'orexpr': s_ast.OrCond,
@@ -710,7 +728,12 @@ def unescape(valu):
     The full list of escaped characters can be found at
     https://docs.python.org/3/reference/lexical_analysis.html#string-and-bytes-literals
     '''
-    ret = ast.literal_eval(valu)
+    try:
+        ret = ast.literal_eval(valu)
+    except ValueError as e:
+        mesg = f"Invalid character in string {repr(valu)}: {e}"
+        raise s_exc.BadSyntax(mesg=mesg, valu=repr(valu)) from None
+
     assert isinstance(ret, str)
     return ret
 
