@@ -44,13 +44,13 @@ TerminalPygMap = {
     'IF': p_t.Keyword,
     'IN': p_t.Keyword,
     'LBRACE': p_t.Punctuation,
+    'LISTTOKN': p_t.Literal.String,
     'LPAR': p_t.Punctuation,
     'LSQB': p_t.Punctuation,
     'MODSET': p_t.Operator,
     'NONQUOTEWORD': p_t.Literal,
     'NOT': p_t.Keyword,
     'NUMBER': p_t.Literal.Number,
-    'NUMBERWS': p_t.Literal.Number,
     'OR': p_t.Keyword,
     'PROPS': p_t.Name,
     'RBRACE': p_t.Punctuation,
@@ -86,6 +86,8 @@ TerminalPygMap = {
     '_EMBEDQUERYSTART': p_t.Punctuation,
     '_EMIT': p_t.Keyword,
     '_FINI': p_t.Keyword,
+    '_HASH': p_t.Punctuation,
+    '_HASHSPACE': p_t.Punctuation,
     '_INIT': p_t.Keyword,
     '_LEFTJOIN': p_t.Punctuation,
     '_LEFTPIVOT': p_t.Punctuation,
