@@ -6,6 +6,25 @@ class BackupLib(s_stormtypes.Lib):
     '''
     A Storm Library for interacting with the backup APIs in the Cortex.
     '''
+    _storm_locals = (
+        {'name': 'run', 'desc': 'Run a Cortex backup.',
+         'type': {'type': 'function', '_funcname': '_runBackup',
+                  'args': (
+                      {'name': 'name', 'type': 'str', 'desc': 'The name of the backup to generate.', 'default': None, },
+                      {'name': 'wait', 'type': 'boolean', 'desc': 'If true, wait for the backup to complete before returning.',
+                       'default': True, },
+                  ),
+                  'returns': {'type': 'str', 'desc': 'The name of the newly created backup.', }}},
+        {'name': 'list', 'desc': 'Get a list of backup names.',
+         'type': {'type': 'function', '_funcname': '_listBackups',
+                  'returns': {'type': 'list', 'desc': 'A list of backup names.', }}},
+        {'name': 'del', 'desc': 'Remove a backup by name.',
+         'type': {'type': 'function', '_funcname': '_delBackup',
+                  'args': (
+                      {'name': 'name', 'type': 'str', 'desc': 'The name of the backup to remove.', },
+                  ),
+                  'returns': {'type': 'null', }}},
+    )
     _storm_lib_path = ('backup',)
 
     def getObjLocals(self):
@@ -16,17 +35,6 @@ class BackupLib(s_stormtypes.Lib):
         }
 
     async def _runBackup(self, name=None, wait=True):
-        '''
-        Run a cortex backup.
-
-        Args:
-            name (str): The name of the backup to generate.
-
-            wait (bool): If true, wait for the backup to complete before returning.
-
-        Returns:
-            str: The name of the newly created backup.
-        '''
         name = await s_stormtypes.tostr(name, noneok=True)
         wait = await s_stormtypes.tobool(wait)
 
@@ -35,23 +43,11 @@ class BackupLib(s_stormtypes.Lib):
         return await self.dyncall('cortex', todo, gatekeys=gatekeys)
 
     async def _listBackups(self):
-        '''
-        Returns a list of backup names.
-
-        Returns:
-            list[str]: A list of backup names.
-        '''
         todo = s_common.todo('getBackups')
         gatekeys = ((self.runt.user.iden, ('backup', 'list'), None),)
         return await self.dyncall('cortex', todo, gatekeys=gatekeys)
 
     async def _delBackup(self, name):
-        '''
-        Remove a backup by name.
-
-        Args:
-            name (str): The name of the backup to remove.
-        '''
         name = await s_stormtypes.tostr(name)
         todo = s_common.todo('delBackup', name)
         gatekeys = ((self.runt.user.iden, ('backup', 'del'), None),)
