@@ -1,6 +1,3 @@
-import synapse.exc as s_exc
-import synapse.common as s_common
-
 import synapse.lib.crypto.coin as s_coin
 import synapse.lib.stormtypes as s_stormtypes
 
