@@ -1,9 +1,4 @@
-import synapse.common as s_common
-
-import synapse.lib.time as s_time
-import synapse.lib.types as s_types
 import synapse.lib.module as s_module
-import synapse.lib.grammar as s_grammar
 
 class EconModule(s_module.CoreModule):
 
@@ -210,6 +205,10 @@ class EconModule(s_module.CoreModule):
                         'doc': 'The currency of the balance amount.'}),
                     ('delta', ('econ:price', {}), {
                         'doc': 'The change since last regular sample.'}),
+                    ('total:received', ('econ:price', {}), {
+                        'doc': 'The total amount of currency received by the account.'}),
+                    ('total:sent', ('econ:price', {}), {
+                        'doc': 'The total amount of currency sent from the account.'}),
                 )),
 
 
