@@ -514,6 +514,12 @@ class ItModule(s_module.CoreModule):
                 ('it:app:yara:rule', ('guid', {}), {
                     'doc': 'A YARA rule unique identifier.',
                 }),
+                ('it:sec:stix:bundle', ('guid', {}), {
+                    'doc': 'A STIX bundle.',
+                }),
+                ('it:sec:stix:indicator', ('guid', {}), {
+                    'doc': 'A STIX indicator pattern.',
+                }),
                 ('it:app:yara:match', ('comp', {'fields': (('rule', 'it:app:yara:rule'), ('file', 'file:bytes'))}), {
                     'doc': 'A YARA rule match to a file.',
                 }),
@@ -1796,6 +1802,26 @@ class ItModule(s_module.CoreModule):
                         'doc': 'The version of the rule at the time of match.'}),
                 )),
 
+                ('it:sec:stix:bundle', {}, (
+                    ('id', ('str', {}), {
+                        'doc': 'The id field from the STIX bundle.'}),
+                )),
+
+                ('it:sec:stix:indicator', {}, (
+                    ('id', ('str', {}), {
+                        'doc': 'The STIX id field from the indicator pattern.'}),
+                    ('name', ('str', {}), {
+                        'doc': 'The name of the STIX indicator pattern.'}),
+                    ('pattern', ('str', {}), {
+                        'doc': 'The STIX indicator pattern text.'}),
+                    ('created', ('time', {}), {
+                        'doc': 'The time that the indicator pattern was first created.'}),
+                    ('updated', ('time', {}), {
+                        'doc': 'The time that the indicator pattern was last modified.'}),
+                    ('labels', ('array', {'type': 'str', 'uniq': True, 'sorted': True}), {
+                        'doc': 'The label strings embedded in the STIX indicator pattern.'}),
+                )),
+
                 ('it:app:yara:rule', {}, (
                     ('text', ('str', {}), {
                         'doc': 'The YARA rule text.',
