@@ -29,6 +29,9 @@ class OuModule(s_module.CoreModule):
                 ('ou:org', ('guid', {}), {
                     'doc': 'A GUID for a human organization such as a company or military unit.',
                 }),
+                ('ou:team', ('guid', {}), {
+                    'doc': 'A GUID for a team within an organization.',
+                }),
                 ('ou:orgtype', ('taxonomy', {}), {
                     'doc': 'An org type taxonomy.',
                     'interfaces': ('taxonomy',),
@@ -47,6 +50,9 @@ class OuModule(s_module.CoreModule):
                 ('ou:industry', ('guid', {}), {
                     'doc': 'An industry classification type.',
                 }),
+                ('ou:industryname', ('str', {'lower': True, 'onespace': True}), {
+                    'doc': 'The name of an industry.',
+                }),
                 ('ou:alias', ('str', {'lower': True, 'regex': r'^[0-9a-z_]+$'}), {
                     'doc': 'An alias for the org GUID.',
                     'ex': 'vertexproject',
@@ -355,6 +361,12 @@ class OuModule(s_module.CoreModule):
                     ('org', ('ou:org', {}), {
                         'doc': 'The org carrying out the campaign.',
                     }),
+                    ('org:name', ('ou:name', {}), {
+                        'doc': 'The name of the org responsible for the campaign. Used for entity resolution.',
+                    }),
+                    ('org:fqdn', ('inet:fqdn', {}), {
+                        'doc': 'The FQDN of the org responsible for the campaign. Used for entity resolution.',
+                    }),
                     ('goal', ('ou:goal', {}), {
                         'doc': 'The assessed primary goal of the campaign.',
                     }),
@@ -394,6 +406,10 @@ class OuModule(s_module.CoreModule):
 
                     ('goal:pop', ('int', {}), {}),
                     ('result:pop', ('int', {}), {}),
+
+                    ('team', ('ou:team', {}), {
+                        'doc': 'The org team responsible for carrying out the campaign.',
+                    }),
                 )),
                 ('ou:orgtype', {}, ()),
                 ('ou:org', {}, (
@@ -466,10 +482,17 @@ class OuModule(s_module.CoreModule):
                         'doc': 'An array of MX domains used by email addresses issued by the org.',
                     }),
                 )),
+                ('ou:team', {}, (
+                    ('org', ('ou:org', {}), {}),
+                    ('name', ('ou:name', {}), {}),
+                )),
                 ('ou:position', {}, (
                     ('org', ('ou:org', {}), {
                         'doc': 'The org which has the position.',
                     }),
+                    ('team', ('ou:team', {}), {
+                        'doc': 'The team that the position is a member of.',
+                    }),
                     ('contact', ('ps:contact', {}), {
                         'doc': 'The contact info for the person who holds the position.',
                     }),
@@ -517,8 +540,10 @@ class OuModule(s_module.CoreModule):
                         'doc': 'A list of types that apply to the contract.'}),
                 )),
                 ('ou:industry', {}, (
-                    ('name', ('str', {'lower': True, 'strip': True}), {
-                        'doc': 'A terse name for the industry.'}),
+                    ('name', ('ou:industryname', {}), {
+                        'doc': 'The name of the industry.'}),
+                    ('names', ('array', {'type': 'ou:industryname', 'uniq': True, 'sorted': True}), {
+                        'doc': 'An array of alternative names for the industry.'}),
                     ('subs', ('array', {'type': 'ou:industry', 'split': ',', 'uniq': True, 'sorted': True}), {
                         'doc': 'An array of sub-industries.'}),
                     ('sic', ('array', {'type': 'ou:sic', 'split': ',', 'uniq': True, 'sorted': True}), {
@@ -532,6 +557,7 @@ class OuModule(s_module.CoreModule):
                         'disp': {'hint': 'text'},
                     }),
                 )),
+                ('ou:industryname', {}, ()),
                 ('ou:hasalias', {}, (
                     ('org', ('ou:org', {}), {
                         'ro': True,
