@@ -243,3 +243,19 @@ class DataModelTest(s_t_utils.SynTest):
         mdef = modl.getModelDefs()
         modl2 = s_datamodel.Model()
         modl2.addDataModels(mdef)
+
+    async def test_model_comp_readonly_props(self):
+        async with self.getTestCore() as core:
+            q = '''
+            syn:type:subof=comp $opts=:opts
+            -> syn:form:type $valu=$node.value()
+            for ($name, $thing) in $opts.fields {
+                $v=$lib.str.format('{v}:{t}', v=$valu, t=$name)  syn:prop=$v
+            }
+            +syn:prop
+            -:ro=1
+            '''
+            nodes = await core.nodes(q)
+            mesg = f'Comp forms with secondary properties that are not read-only ' \
+                   f'are present in the model: {[n.ndef[1] for n in nodes]}'
+            self.len(0, nodes, mesg)
