@@ -1,8 +1,10 @@
 import synapse.exc as s_exc
 
-import synapse.lib.stormlib.cell as s_cell
+import synapse.lib.const as s_const
+import synapse.lib.stormlib.cell as s_stormlib_cell
 
 import synapse.tests.utils as s_test
+import synapse.tests.test_lib_stormsvc as s_t_stormsvc
 
 class StormCellTest(s_test.SynTest):
 
@@ -25,9 +27,9 @@ class StormCellTest(s_test.SynTest):
 
             # New cores have stormvar set to the current max version fix
             vers = await core.callStorm('return ( $lib.globals.get($key) )',
-                                        {'vars': {'key': s_cell.runtime_fixes_key}})
+                                        {'vars': {'key': s_stormlib_cell.runtime_fixes_key}})
             self.nn(vers)
-            self.eq(vers, s_cell.getMaxHotFixes())
+            self.eq(vers, s_stormlib_cell.getMaxHotFixes())
 
             user = await core.addUser('bob')
             opts = {'user': user.get('iden')}
@@ -44,6 +46,32 @@ class StormCellTest(s_test.SynTest):
             with self.raises(s_exc.AuthDeny):
                 await core.callStorm('return ( $lib.cell.getHealthCheck() )', opts=opts)
 
+    async def test_stormlib_cell_uptime(self):
+
+        async with self.getTestCoreProxSvc(s_t_stormsvc.StormvarServiceCell) as (core, prox, svc):
+
+            day = await core.callStorm('return($lib.time.format($lib.time.now(), "%Y-%m-%d"))')
+
+            msgs = await core.stormlist('uptime')
+            self.stormIsInPrint('up 00:00:', msgs)
+            self.stormIsInPrint(f'since {day}', msgs)
+
+            msgs = await core.stormlist('uptime stormvar')
+            self.stormIsInPrint('up 00:00:', msgs)
+            self.stormIsInPrint(f'since {day}', msgs)
+
+            msgs = await core.stormlist('uptime newp')
+            self.stormIsInErr('No service with name/iden: newp', msgs)
+
+            svc.starttime = svc.starttime - (1 * s_const.day + 2 * s_const.hour) / 1000
+            msgs = await core.stormlist('uptime stormvar')
+            self.stormIsInPrint('up 1D 02:00:', msgs)
+            self.stormIsInPrint(day, msgs)
+
+            resp = await core.callStorm('return($lib.cell.uptime())')
+            self.eq(core.startms, resp['starttime'])
+            self.lt(resp['uptime'], s_const.minute)
+
     async def test_stormfix_autoadds(self):
 
         async def get_regression_views(cortex):
@@ -169,7 +197,7 @@ class StormCellTest(s_test.SynTest):
             self.len(0, await core.nodes('it:sec:cpe:v2_2', opts={'view': view2}))
 
             # Set the hotfix valu
-            opts = {'vars': {'key': s_cell.runtime_fixes_key, 'valu': (2, 0, 0)}}
+            opts = {'vars': {'key': s_stormlib_cell.runtime_fixes_key, 'valu': (2, 0, 0)}}
             await core.callStorm('$lib.globals.set($key, $valu)', opts)
 
             # Run all hotfixes.
